/* Blinker
   Copyright 2011 Stefan Schuermans <stefan@blinkenarea.org>
   Copyleft GNU public license - http://www.gnu.org/copyleft/gpl.html
   a blinkenarea.org project */

#ifndef PRINTER_H
#define PRINTER_H

#include <string>

#include <BlinkenLib/BlinkenFrame.h>

#include "Directory.h"
#include "File.h"
#include "SettingFile.h"
#include "StreamMgr.h"
#include "StreamRecv.h"

namespace Blinker {

/// a stream printer
class Printer: public StreamRecv
{
public:
  /**
   * @brief constructor
   * @param[in] streamMgr stream manager
   * @param[in] dirBase base directory
   */
  Printer(StreamMgr &streamMgr, const Directory &dirBase);

  /// virtual destructor
  virtual ~Printer();

private:
  /// copy constructor disabled
  Printer(const Printer & that);

  /// assignment operator disabled
  const Printer& operator=(const Printer &that);

public:
  /**
   * @brief set current frame
   * @param[in] pFrame current frame
   */
  virtual void setFrame(stBlinkenFrame *pFrame);

  /// set current frame to none
  virtual void setNoFrame();

protected:
  StreamMgr                &m_streamMgr;   ///< stream manager
  Directory                m_dirBase;      ///< base directory
  SettingFile              m_fileInStream; ///< input stream name file
  std::string              m_nameInStream; ///< name of input stream
  Stream                   *m_pInStream;   ///< input stream
}; // class Printer

} // namespace Blinker

#endif // #ifndef PRINTER_H

